@@ -1,23 +1,35 @@
+import logging
+import time
+
+import configargparse
+import requests
+import requests.exceptions
+
 from cleargrid.gps import get_client
 from cleargrid.logging import add_log_file
-import requests
-import logging
-import configargparse
 
 
-def watch(w):
+def watch(w, retries=5):
     for i, p in enumerate(w.stream):
+        attempt = retries
         if hasattr(p, "position"):
-            requests.post(
-                "http://127.0.0.1/update",
-                json={
-                    "location": (
-                        p.timestamp.timestamp,
-                        p.position.latitude,
-                        p.position.longitude,
-                    )
-                },
-            )
+            try:
+                requests.post(
+                    "http://127.0.0.1/update",
+                    json={
+                        "location": (
+                            p.timestamp.timestamp,
+                            p.position.latitude,
+                            p.position.longitude,
+                        )
+                    },
+                )
+            except requests.exceptions.ConnectionError as e:
+                if not attempt:
+                    raise e
+                logging.warn("Connection to interface host failed")
+                time.sleep(2 ** (retries - attempt))
+                attempt -= 1
 
 
 def main():
@@ -38,6 +50,8 @@ def main():
         with c.watch() as w:
             try:
                 watch(w)
+            except requests.exceptions.ConnectionError:
+                logging.error("Unable to connect to interface host")
             except Exception:
                 logging.exception("Error in Watcher, retrying")
 
